Documentation
¶
Index ¶
- Constants
- Variables
- type PermissionSet
- func (*PermissionSet) Descriptor() ([]byte, []int)deprecated
- func (x *PermissionSet) GetPermissions() []auth.Permission
- func (x *PermissionSet) GetTaint() *Taint
- func (*PermissionSet) ProtoMessage()
- func (x *PermissionSet) ProtoReflect() protoreflect.Message
- func (x *PermissionSet) Reset()
- func (x *PermissionSet) String() string
- type Permissions
- func (*Permissions) Descriptor() ([]byte, []int)deprecated
- func (x *Permissions) GetNoPermissions() bool
- func (x *Permissions) GetSets() []*PermissionSet
- func (x *Permissions) GetWip() booldeprecated
- func (*Permissions) ProtoMessage()
- func (x *Permissions) ProtoReflect() protoreflect.Message
- func (x *Permissions) Reset()
- func (x *Permissions) String() string
- type Taint
Constants ¶
const ( Default_Permissions_Wip = bool(false) Default_Permissions_NoPermissions = bool(false) )
Default values for Permissions fields.
Variables ¶
var ( // add annotations to method options // // optional annotations.Permissions authz = 560007; E_Authz = &file_annotations_authz_proto_extTypes[0] )
Extension fields to descriptorpb.MethodOptions.
var File_annotations_authz_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type PermissionSet ¶
type PermissionSet struct {
Permissions []auth.Permission `protobuf:"varint,1,rep,name=permissions,enum=api.commons.auth.Permission" json:"permissions,omitempty"`
Taint *Taint `protobuf:"bytes,2,opt,name=taint" json:"taint,omitempty"`
// contains filtered or unexported fields
}
func (*PermissionSet) Descriptor
deprecated
func (*PermissionSet) Descriptor() ([]byte, []int)
Deprecated: Use PermissionSet.ProtoReflect.Descriptor instead.
func (*PermissionSet) GetPermissions ¶
func (x *PermissionSet) GetPermissions() []auth.Permission
func (*PermissionSet) GetTaint ¶ added in v1.8.4
func (x *PermissionSet) GetTaint() *Taint
func (*PermissionSet) ProtoMessage ¶
func (*PermissionSet) ProtoMessage()
func (*PermissionSet) ProtoReflect ¶
func (x *PermissionSet) ProtoReflect() protoreflect.Message
func (*PermissionSet) Reset ¶
func (x *PermissionSet) Reset()
func (*PermissionSet) String ¶
func (x *PermissionSet) String() string
type Permissions ¶
type Permissions struct {
// A list of permission sets - atleast one set must exist in the list
// to allow access.
Sets []*PermissionSet `protobuf:"bytes,1,rep,name=sets" json:"sets,omitempty"`
// WIP inject PERMISSION_DEV into the required list
// don't use it, it will be removed soon
//
// Deprecated: Marked as deprecated in annotations/authz.proto.
Wip *bool `protobuf:"varint,2,opt,name=wip,def=0" json:"wip,omitempty"`
// Indicate that the method will use no permissions - it will be public.
// Be careful with this.
NoPermissions *bool `protobuf:"varint,3,opt,name=no_permissions,json=noPermissions,def=0" json:"no_permissions,omitempty"`
// contains filtered or unexported fields
}
Permissions - annotation object
func (*Permissions) Descriptor
deprecated
func (*Permissions) Descriptor() ([]byte, []int)
Deprecated: Use Permissions.ProtoReflect.Descriptor instead.
func (*Permissions) GetNoPermissions ¶
func (x *Permissions) GetNoPermissions() bool
func (*Permissions) GetSets ¶
func (x *Permissions) GetSets() []*PermissionSet
func (*Permissions) GetWip
deprecated
func (x *Permissions) GetWip() bool
Deprecated: Marked as deprecated in annotations/authz.proto.
func (*Permissions) ProtoMessage ¶
func (*Permissions) ProtoMessage()
func (*Permissions) ProtoReflect ¶
func (x *Permissions) ProtoReflect() protoreflect.Message
func (*Permissions) Reset ¶
func (x *Permissions) Reset()
func (*Permissions) String ¶
func (x *Permissions) String() string
type Taint ¶ added in v1.8.4
type Taint struct {
// id of the request message field that will be checked.
Id *int32 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
// value that the request mesage field with id is required to match.
Value *int32 `protobuf:"varint,2,opt,name=value" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*Taint) Descriptor
deprecated
added in
v1.8.4
func (*Taint) ProtoMessage ¶ added in v1.8.4
func (*Taint) ProtoMessage()
func (*Taint) ProtoReflect ¶ added in v1.8.4
func (x *Taint) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.